@@ -1,6 +1,4 @@
 #include "derivation.h"
-#include <string>
-#include <vector>
 
 using namespace std;
 
